[llvm-commits] [llvm] r76440 - /llvm/trunk/include/llvm/Operator.h

Dan Gohman gohman at apple.com
Mon Jul 20 10:51:11 PDT 2009


Author: djg
Date: Mon Jul 20 12:51:10 2009
New Revision: 76440

URL: http://llvm.org/viewvc/llvm-project?rev=76440&view=rev
Log:
Drop UDivOperator and introduce SDivOperator. Thanks to Chris
for noticing this.

Modified:
    llvm/trunk/include/llvm/Operator.h

Modified: llvm/trunk/include/llvm/Operator.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/Operator.h?rev=76440&r1=76439&r2=76440&view=diff

==============================================================================
--- llvm/trunk/include/llvm/Operator.h (original)
+++ llvm/trunk/include/llvm/Operator.h Mon Jul 20 12:51:10 2009
@@ -100,9 +100,9 @@
   }
 };
 
 /// UDivOperator - An Operator with opcode Instruction::UDiv.
 ///
-class UDivOperator : public Operator {
+class SDivOperator : public Operator {
 public:
   /// isExact - Test whether this division is known to be exact, with
   /// zero remainder.
@@ -114,12 +114,12 @@
   }
 
   // Methods for support type inquiry through isa, cast, and dyn_cast:
-  static inline bool classof(const UDivOperator *) { return true; }
+  static inline bool classof(const SDivOperator *) { return true; }
   static inline bool classof(const ConstantExpr *CE) {
-    return CE->getOpcode() == Instruction::UDiv;
+    return CE->getOpcode() == Instruction::SDiv;
   }
   static inline bool classof(const Instruction *I) {
-    return I->getOpcode() == Instruction::UDiv;
+    return I->getOpcode() == Instruction::SDiv;
   }
   static inline bool classof(const Value *V) {
     return (isa<Instruction>(V) && classof(cast<Instruction>(V))) ||
@@ -100,9 +100,9 @@
 };
 
-/// UDivOperator - An Operator with opcode Instruction::UDiv.
+/// SDivOperator - An Operator with opcode Instruction::SDiv.
 ///





More information about the llvm-commits mailing list